@@ -1,4 +1,4 @@
-{-# LANGUAGE TypeFamilies #-}
+{-# LANGUAGE CPP, MultiParamTypeClasses, OverloadedStrings, RecordWildCards, QuasiQuotes, TemplateHaskell, TypeFamilies, TypeSynonymInstances, FlexibleInstances #-}
 {-
 
 Define the web application's foundation, in the usual Yesod style.
@@ -8,7 +8,9 @@ See a default Yesod app's comments for more details of each part.
 module Foundation where
 
 import Prelude
+#if !MIN_VERSION_base(4,8,0)
 import Control.Applicative ((<$>))
+#endif
 import Data.IORef
 import Yesod
 import Yesod.Static
@@ -25,6 +27,7 @@ import Settings (staticRoot, widgetFile, Extra (..))
 import Settings (staticDir)
 import Text.Jasmine (minifym)
 #endif
+import Text.Blaze.Html.Renderer.String (renderHtml)
 import Text.Hamlet (hamletFile)
 
 import Hledger.Web.Options
@@ -37,10 +40,10 @@ import Data.List
 import Data.Maybe
 import Data.Text as Text (Text,pack,unpack)
 import Data.Time.Calendar
-import System.FilePath (takeFileName)
 #if BLAZE_HTML_0_4
-import Text.Blaze (preEscapedString)
+import Text.Blaze (preEscapedString, Markup)
 #else
+import Text.Blaze (Markup)
 import Text.Blaze.Internal (preEscapedString)
 #endif
 import Text.JSON
@@ -105,7 +108,8 @@ instance Yesod App where
 
     defaultLayout widget = do
         master <- getYesod
-        mmsg <- getMessage
+        lastmsg <- getMessage
+        vd@VD{..} <- getViewData
 
         -- We break up the default layout into two components:
         -- default-layout is the contents of the body tag, and
@@ -141,7 +145,6 @@ instance Yesod App where
             $(widgetFile "default-layout")
 
         staticRootUrl <- (staticRoot . settings) <$> getYesod
-        vd@VD{..} <- getViewData
         withUrlRenderer $(hamletFile "templates/default-layout-wrapper.hamlet")
 
     -- This is done to provide an optimization for serving static files from
@@ -202,7 +205,9 @@ data ViewData = VD {
     ,aopts        :: [QueryOpt] -- ^ query options parsed from the accounts sidebar query expr
     ,showpostings :: Bool       -- ^ current p parameter, 1 or 0 shows/hides all postings where applicable
     ,showsidebar  :: Bool       -- ^ current showsidebar cookie value
-    }
+    } deriving (Show)
+
+instance Show Text.Blaze.Markup where show _ = "<blaze markup>"
 
 -- | Make a default ViewData, using day 0 as today's date.
 nullviewdata :: ViewData
@@ -233,8 +238,9 @@ getViewData :: Handler ViewData
 getViewData = do
   app        <- getYesod
   let opts@WebOpts{cliopts_=copts@CliOpts{reportopts_=ropts}} = appOpts app
-  (j, err)   <- getCurrentJournal app copts{reportopts_=ropts{no_elide_=True}}
-  msg        <- getMessageOr err
+  (j, merr)  <- getCurrentJournal app copts{reportopts_=ropts{no_elide_=True}}
+  lastmsg    <- getLastMessage
+  let msg = maybe lastmsg (Just . toHtml) merr
   Just here  <- getCurrentRoute
   today      <- liftIO getCurrentDay
   q          <- getParameterOrNull "q"
@@ -276,11 +282,10 @@ getViewData = do
       getParameterOrNull :: String -> Handler String
       getParameterOrNull p = unpack `fmap` fromMaybe "" <$> lookupGetParam (pack p)
 
--- | Get the message set by the last request, or the newer message provided, if any.
-getMessageOr :: Maybe String -> Handler (Maybe Html)
-getMessageOr mnewmsg = do
-  oldmsg <- getMessage
-  return $ maybe oldmsg (Just . toHtml) mnewmsg
+-- | Get the message that was set by the last request, in a
+-- referentially transparent manner (allowing multiple reads).
+getLastMessage :: Handler (Maybe Html)
+getLastMessage = cached getMessage
 
 -- add form dialog, part of the default template
 
@@ -335,7 +340,7 @@ addform _ vd@VD{..} = [hamlet|
      <table style="width:100%;">
       <tr#descriptionrow>
        <td>
-        <input #date        .typeahead .form-control .input-lg type=text size=15 name=date placeholder="Date" value=#{date}>
+        <input #date        .typeahead .form-control .input-lg type=text size=15 name=date placeholder="Date" value=#{defdate}>
        <td>
         <input #description .typeahead .form-control .input-lg type=text size=40 name=description placeholder="Description">
    $forall n <- postingnums
@@ -345,11 +350,12 @@ addform _ vd@VD{..} = [hamlet|
      Tab in last field for <a .small href="#" onclick="addformAddPosting(); return false;">more</a> (or ctrl +, ctrl -)
 |]
  where
-  date = "today" :: String
+  defdate = "today" :: String
   dates = ["today","yesterday","tomorrow"] :: [String]
   descriptions = sort $ nub $ map tdescription $ jtxns j
   accts = sort $ journalAccountNamesUsed j
-  listToJsonValueObjArrayStr as  = preEscapedString $ encode $ JSArray $ map (\a -> JSObject $ toJSObject [("value", showJSON a)]) as
+  escapeJSSpecialChars = regexReplaceCI "</script>" "<\\/script>" -- #236
+  listToJsonValueObjArrayStr as  = preEscapedString $ escapeJSSpecialChars $ encode $ JSArray $ map (\a -> JSObject $ toJSObject [("value", showJSON a)]) as
   numpostings = 4
   postingnums = [1..numpostings]
   postingfields :: ViewData -> Int -> HtmlUrl AppRoute
@@ -370,22 +376,31 @@ addform _ vd@VD{..} = [hamlet|
          |]
        | otherwise = [hamlet|
           <td #addbtncell style="text-align:right;">
-           <input type=hidden name=action value=add>
            <button type=submit .btn .btn-lg name=submit>add
-           $if length files' > 1
-            <br>to: ^{journalselect files'}
+           $if length filepaths > 1
+            <br>
+            <span class="input-lg">to:
+            ^{journalselect filepaths}
          |]
        where
         amtvar = "amount" ++ show n
         amtph = "Amount " ++ show n
-        files' = [(takeFileName f,s) | (f,s) <- files j]
+        filepaths = map fst $ files j
 
            -- <button .btn style="font-size:18px;" type=submit title="Add this transaction">Add
 
-journalselect :: [(FilePath,String)] -> HtmlUrl AppRoute
-journalselect journalfiles = [hamlet|
-<select id=journalselect name=journal onchange="/*journalSelect(event)*/">
- $forall f <- journalfiles
-  <option value=#{fst f}>#{fst f}
+journalselect :: [FilePath] -> HtmlUrl AppRoute
+journalselect journalfilepaths = [hamlet|
+<select id=journalselect name=journal onchange="/*journalSelect(event)*/" class="form-control input-lg" style="width:auto; display:inline-block;">
+ $forall p <- journalfilepaths
+  <option value=#{p}>#{p}
+|]
+
+journalradio :: [FilePath] -> HtmlUrl AppRoute
+journalradio journalfilepaths = [hamlet|
+ $forall p <- journalfilepaths
+  <div style="white-space:nowrap;">
+   <span class="input-lg" style="position:relative; top:-8px; left:8px;">#{p}
+   <input name=journal type=radio value=#{p} class="form-control" style="width:auto; display:inline;">
 |]
 
