@@ -1,3 +1,4 @@
+{-# LANGUAGE CPP, OverloadedStrings #-}
 {-|
 
 hledger-web - a hledger add-on providing a web interface.
@@ -18,13 +19,15 @@ import Data.String
 import Network.Wai.Handler.Warp (runSettings, defaultSettings, setPort)
 import Network.Wai.Handler.Launch (runUrlPort)
 --
-import Prelude hiding (putStrLn)
+#if !MIN_VERSION_base(4,8,0)
 import Control.Applicative ((<$>))
+#endif
 import Control.Monad (when)
 import Data.Text (pack)
 import System.Exit (exitSuccess)
 import System.IO (hFlush, stdout)
 import Text.Printf
+import Prelude hiding (putStrLn)
 
 import Hledger
 import Hledger.Utils.UTF8IOCompat (putStrLn)
@@ -44,12 +47,13 @@ runWith opts
   | "version" `inRawOpts` (rawopts_ $ cliopts_ opts)         = putStrLn prognameandversion >> exitSuccess
   | "binary-filename" `inRawOpts` (rawopts_ $ cliopts_ opts) = putStrLn (binaryfilename progname)
   | otherwise = do
-    requireJournalFileExists =<< journalFilePathFromOpts (cliopts_ opts)
+    requireJournalFileExists =<< (head `fmap` journalFilePathFromOpts (cliopts_ opts)) -- XXX head should be safe for now
     withJournalDo' opts web
 
 withJournalDo' :: WebOpts -> (WebOpts -> Journal -> IO ()) -> IO ()
 withJournalDo' opts cmd = do
-  journalFilePathFromOpts (cliopts_ opts) >>= readJournalFile Nothing Nothing True >>=
+  -- XXX head should be safe for now
+  (head `fmap` journalFilePathFromOpts (cliopts_ opts)) >>= readJournalFile Nothing Nothing True >>=
     either error' (cmd opts . journalApplyAliases (aliasesFromOpts $ cliopts_ opts))
 
 -- | The web command.
