@@ -1,3 +1,4 @@
+{-# LANGUAGE CPP #-}
 module Import
     ( module Import
     ) where
@@ -6,7 +7,9 @@ import           Prelude              as Import hiding (head, init, last,
                                                  readFile, tail, writeFile)
 import           Yesod                as Import hiding (Route (..))
 
+#if !MIN_VERSION_base(4,8,0)
 import           Control.Applicative  as Import (pure, (<$>), (<*>))
+#endif
 import           Data.Text            as Import (Text)
 
 import           Foundation           as Import
@@ -15,8 +18,10 @@ import           Settings.Development as Import
 import           Settings.StaticFiles as Import
 
 #if __GLASGOW_HASKELL__ >= 704
-import           Data.Monoid          as Import
-                                                 (Monoid (mappend, mempty, mconcat),
+import           Data.Monoid          as Import (
+#if !MIN_VERSION_base(4,8,0)
+                                                 Monoid (mappend, mempty, mconcat),
+#endif
                                                  (<>))
 #else
 import           Data.Monoid          as Import
