@@ -6,7 +6,7 @@
 $(document).ready(function() {
 
   // show add form if ?add=1
-  if ($.url.param('add')) { addformShow(); }
+  if ($.url.param('add')) { addformShow(showmsg=true); }
 
   // sidebar account hover handlers
   $('#sidebar td a').mouseenter(function(){ $(this).parent().addClass('mouseover'); });
@@ -16,7 +16,7 @@ $(document).ready(function() {
   // 'body' seems to hold focus better than document in FF
   $('body').bind('keydown', 'h',       function(){ $('#helpmodal').modal('toggle'); return false; });
   $('body').bind('keydown', 'shift+/', function(){ $('#helpmodal').modal('toggle'); return false; });
-  $('body').bind('keydown', 'j',       function(){ location.href = '/journal'; return false; });
+  $('body').bind('keydown', 'j',       function(){ location.href = document.hledgerWebBaseurl+'/journal'; return false; });
   $('body').bind('keydown', 's',       function(){ sidebarToggle(); return false; });
   $('body').bind('keydown', 'a',       function(){ addformShow(); return false; });
   $('body').bind('keydown', 'n',       function(){ addformShow(); return false; });
@@ -126,8 +126,9 @@ function registerChartClick(ev, pos, item) {
 //----------------------------------------------------------------------
 // ADD FORM
 
-function addformShow() {
-  addformReset();
+function addformShow(showmsg) {
+  showmsg = typeof showmsg !== 'undefined' ? a : false;
+  addformReset(showmsg);
   $('#addmodal')
     .on('shown.bs.modal', function (e) {
       addformFocus();
@@ -136,13 +137,15 @@ function addformShow() {
 }
 
 // Make sure the add form is empty and clean for display.
-function addformReset() {
+function addformReset(showmsg) {
+  showmsg = typeof showmsg !== 'undefined' ? a : false;
   if ($('form#addform').length > 0) {
+    if (!showmsg) $('div#message').html('');
     $('form#addform')[0].reset();
-    $('input#date').val('today');
     // reset typehead state (though not fetched completions)
     $('.typeahead').typeahead('val', '');
     $('.tt-dropdown-menu').hide();
+    $('input#date').val('today');
   }
 }
 
@@ -242,7 +245,7 @@ function addformDeletePosting() {
   focuslost = focuslost || 
     $('#addform tr.posting:last > td:last input:last').is(':focus');
   // replace new last row's amount field with the button
-  $('#addform tr.posting:last > td:last').html(btn);
+  $('#addform tr.posting:last > td:last').css('text-align','right').html(btn);
   // if deleted row had focus, focus the new last row
   if (focuslost) $('#addform tr.posting:last > td:first input:last').focus();
 }
